summaryrefslogtreecommitdiffhomepage
path: root/dev/Kernel/HALKit/ARM64/HalApplicationProcessor.cc
diff options
context:
space:
mode:
Diffstat (limited to 'dev/Kernel/HALKit/ARM64/HalApplicationProcessor.cc')
-rw-r--r--dev/Kernel/HALKit/ARM64/HalApplicationProcessor.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/dev/Kernel/HALKit/ARM64/HalApplicationProcessor.cc b/dev/Kernel/HALKit/ARM64/HalApplicationProcessor.cc
index c2bea7e3..415ad5b1 100644
--- a/dev/Kernel/HALKit/ARM64/HalApplicationProcessor.cc
+++ b/dev/Kernel/HALKit/ARM64/HalApplicationProcessor.cc
@@ -28,7 +28,7 @@
// ================================================================= //
-namespace Kernel
+namespace NeOS
{
struct PROCESS_CONTROL_BLOCK final
{
@@ -133,4 +133,4 @@ namespace Kernel
return NO;
}
-} // namespace Kernel \ No newline at end of file
+} // namespace NeOS \ No newline at end of file